/**
  ******************************************************************************
  * @file    vk16k33_driver.c
  * @author  kevin_guo
  * @version V1.0.0
  * @date    06-05-2017
  * @brief   This file provides tuner io i2c vk16k33_driver functions.
  ******************************************************************************
  * @copy
  */ 
  
/* Includes ------------------------------------------------------------------*/
#include "vk16k33_driver.h"

/* extern variables ----------------------------------------------------------*/
unsigned char write_buf[16];
unsigned char read_buf[16];
unsigned char vk16k33_key[6];
/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
/* Private function prototypes -----------------------------------------------*/
/* Private function ----------------------------------------------------------*/

/*******************************************************************************
* Function Name  : VK16K33_delay_nus
* Description    : ʱ1uS
* Input          : n->ʱʱnuS
* Output         : None
* Return         : None
*******************************************************************************/
void VK16K33_delay_nus(unsigned int n)	   
{
	unsigned char i;
	while(n--)
	{
		i=40;
		while(i--)
		{//nopָݵƬӦ޸
			__nop();
		}
	}
}
/*******************************************************************************
* Function Name  : VK16K33_delay_nms
* Description    : ʱ1mS
* Input          : n->ʱʱnmS
* Output         : None
* Return         : None
*******************************************************************************/
void VK16K33_delay_nms(unsigned long int n)
{
	while(n--)
	{
		VK16K33_delay_nus(1000);
	}
}
//GPIO ģI2C 
/*************************************************************
*ƣVK16K33_I2CStart
*ܣI2Cʼź
*
*
*    עʱ߸ʱɸߵ͵䣬ʾI2Cʼź
**************************************************************/
void VK16K33_I2CStart( void )
{
  VK16K33_SCL_HIGH;
  VK16K33_delay_nus(1);
  VK16K33_SDA_HIGH;
  VK16K33_delay_nus(1);
  VK16K33_SDA_LOW;
  VK16K33_delay_nus(1);
}

/*************************************************************
*ƣVK16K33_I2CStop
*ܣI2Cֹͣź
*
*
*    עʱ߸ʱɵ͵ߵ䣬ʾI2Cֹͣź
**************************************************************/
void VK16K33_I2CStop( void )
{
  VK16K33_delay_nus(1);
  VK16K33_SCL_HIGH;
  VK16K33_SDA_LOW;
  VK16K33_delay_nus(1);
  VK16K33_SDA_HIGH;
  VK16K33_delay_nus(1);


}

/*************************************************************
*ƣVK16K33_I2CSlaveAck
*ܣI2Cӻ豸Ӧѯ
*
*
*    ע
**************************************************************/
unsigned char VK16K33_I2CSlaveAck( void )
{
  unsigned int TimeOut;
  unsigned char RetValue;
  
  VK16K33_SCL_LOW;
  VK16K33_delay_nus(1);
  VK16K33_SCL_HIGH;
  VK16K33_delay_nus(1);
  TimeOut = 10000;
  while( TimeOut-- > 0 )
  {
    if( VK16K33_SDA_IO==0 )
    {
      RetValue = 0;
      break;
    }
    else
    {
      RetValue = 1;
    }
  }
  VK16K33_SCL_LOW;
  VK16K33_delay_nus(1);
  
  return RetValue;
}
/*************************************************************
*ƣVK16K33_I2CSendAck
*ܣӦ
*
*
*    ע
**************************************************************/
void VK16K33_I2CSendAck( void )
{  
  VK16K33_SCL_LOW;
  VK16K33_SDA_LOW;
  VK16K33_delay_nus(1);
  VK16K33_SCL_HIGH;
  VK16K33_delay_nus(1);
  VK16K33_SCL_LOW;
  VK16K33_SDA_HIGH;
  VK16K33_delay_nus(1);
}
/*************************************************************
*ƣVK16K33_I2CSendNAck
*ܣNAck
*
*
*    ע
**************************************************************/
void VK16K33_I2CSendNAck( void )
{
  VK16K33_SCL_LOW;
  VK16K33_SDA_HIGH;
  VK16K33_delay_nus(1);
  VK16K33_SCL_HIGH;
  VK16K33_delay_nus(1);
  VK16K33_SCL_LOW;
  VK16K33_SDA_LOW;
  VK16K33_delay_nus(1);
}

/*************************************************************
*ƣVK16K33_I2CWriteByte
*ܣI2Cдһֽ
*byte-Ҫд
*
*    ע
**************************************************************/
void VK16K33_I2CWriteByte( unsigned char byte )
{
  unsigned char i;

  for( i=0; i<8; i++ )
  {
    VK16K33_SCL_LOW;
    VK16K33_delay_nus(1);
    if( 0X80 & byte )
      VK16K33_SDA_HIGH;
    else
      VK16K33_SDA_LOW;
    byte <<= 1;
    VK16K33_SCL_HIGH;
    VK16K33_delay_nus(1);		
  }

}

/*************************************************************
*ƣVK16K33_I2CReadByte
*ܣI2Cһֽ
*
*
*    ע
**************************************************************/
unsigned char VK16K33_I2CReadByte( void )
{
  unsigned char i;
  unsigned char ReadValue = 0;
  unsigned char bit;

  for( i=0; i<8; i++ )
  {
    VK16K33_SCL_LOW;
    VK16K33_delay_nus(1);
    if( VK16K33_SDA_IO==1 )
      bit = 0X01;
    else
      bit = 0x00;
      
    ReadValue = (ReadValue<<1)|bit;
    VK16K33_SCL_HIGH;
    VK16K33_delay_nus(1);
  }

  return ReadValue;
}

/*************************************************************
*: VK16K33WriteCmd
*: I2C_IOVK16K33дһֽ
*: cmd  д
*0: д1:д
*    ע
**************************************************************/
unsigned char VK16K33WriteCmd(uint8_t cmd )
{
  VK16K33_I2CStart();
	
  VK16K33_I2CWriteByte( VK16K33_DEVADDR|0x00 );
  if( 1 == VK16K33_I2CSlaveAck() )
  {
    return 1;
  }
  VK16K33_I2CWriteByte( cmd );
  if( 1 == VK16K33_I2CSlaveAck() )
  {
    return 1;
  }
  VK16K33_I2CStop();
 
  return 0;
}

/*************************************************************
*: VK16K33WriteOneData
*: I2C_IOVK16K33д1ֽ1ֽ
*: cmd   д
*          data  д
*0: д1:д
*    ע
**************************************************************/
unsigned char VK16K33WriteOneData( unsigned char cmdaddr, unsigned char data )
{
	//START ź
  VK16K33_I2CStart();
  //SLAVEַ
  VK16K33_I2CWriteByte( VK16K33_DEVADDR|0x00 );
  if( 1 == VK16K33_I2CSlaveAck() )
  {
    return 1;
  }
	//дַ
  VK16K33_I2CWriteByte( cmdaddr );
  if( 1 == VK16K33_I2CSlaveAck() )
  {
    return 1;
  }
	//д
  VK16K33_I2CWriteByte( data );
  if( 1 == VK16K33_I2CSlaveAck() )
  {
    return 1;
  }
	//STOPź
  VK16K33_I2CStop();
 
  return 0;
}
/*************************************************************
*: VK16K33WriteNData
*: I2C_IOVK16K33д1ֽ/ַnֽ
*: cmdaddr   д/ַ
*					 databuf   ݻ
*          num       дݸ
*1:д   0:д
*    ע
**************************************************************/
unsigned char VK16K33WriteNData( unsigned char cmdaddr, unsigned char* databuf, unsigned char num)
{
	unsigned char i;
	//STARTź	
  VK16K33_I2CStart();
  //SLAVEַ
  VK16K33_I2CWriteByte( VK16K33_DEVADDR|0x00 );
  if( 1 == VK16K33_I2CSlaveAck() )
  {
    return 1;
  }
	//ʾRAMʼַ
  VK16K33_I2CWriteByte( cmdaddr );
  if( 1 == VK16K33_I2CSlaveAck() )
  {
    return 1;
  }
	//numݵʾRAM
	for(i=0;i<num;i++)
	{
		VK16K33_I2CWriteByte(*databuf++);
		if( 1 == VK16K33_I2CSlaveAck() )
		{
			return 1;
		}
	}
	
  VK16K33_I2CStop();
  //STOPź
  return 0;
}

/*************************************************************
*: VK16K33ReadNData
*: I2C_IOVK16K33numֽ
*: cmdaddr Ĵַַ
*          num     Ҫݸ
*
*    ע
**************************************************************/
unsigned char VK16K33ReadNData(unsigned char cmdaddr, unsigned char num)
{
  unsigned char i = 0;
	//STARTź	
  VK16K33_I2CStart();
  //SLAVEַ Write
  VK16K33_I2CWriteByte( VK16K33_DEVADDR|0x00 );
  if( 1 == VK16K33_I2CSlaveAck() )
  {
    return 1;
  }
	//д
  VK16K33_I2CWriteByte( cmdaddr );
  if( 1 == VK16K33_I2CSlaveAck() )
  {
    return 1;
  }	
	//STOPź
  VK16K33_I2CStop();
	//STARTź
  VK16K33_I2CStart();
	//SLAVEַ Read
  VK16K33_I2CWriteByte( VK16K33_DEVADDR|0x01 );
  if( 1 == VK16K33_I2CSlaveAck() )
  {
    return 1;
  }
	//ȡnum
	if(num>1)
	{
		for(i=0;i<num-1;i++)
		{
			read_buf[i]=VK16K33_I2CReadByte();
			VK16K33_I2CSendAck();
		}	
	}
	read_buf[num-1]=VK16K33_I2CReadByte();
	VK16K33_I2CSendNAck();
	//STOPź
  VK16K33_I2CStop();
 
  return 0;
}

/*************************************************************
*: VK16K33Readnkey
*: I2C_IOVK16K33
*: cmdaddr ݵַ
*          num     Ҫİݸ
*
*    ע
**************************************************************/
unsigned char VK16K33Readnkey(unsigned char cmdaddr, unsigned char num)
{
  unsigned char i = 0;
	//STARTź	
  VK16K33_I2CStart();
  //SLAVEַ Write
  VK16K33_I2CWriteByte( VK16K33_DEVADDR|0x00 );
  if( 1 == VK16K33_I2CSlaveAck() )
  {
    return 1;
  }
	//д
  VK16K33_I2CWriteByte( cmdaddr );
  if( 1 == VK16K33_I2CSlaveAck() )
  {
    return 1;
  }	
	//STOPź
  VK16K33_I2CStop();
	//STARTź
  VK16K33_I2CStart();
	//SLAVEַ Read
  VK16K33_I2CWriteByte( VK16K33_DEVADDR|0x01 );
  if( 1 == VK16K33_I2CSlaveAck() )
  {
    return 1;
  }
	//ȡnum
	if(num>1)
	{
		for(i=0;i<num-1;i++)
		{
			vk16k33_key[i]=VK16K33_I2CReadByte();
			VK16K33_I2CSendAck();
		}	
	}
	vk16k33_key[num-1]=VK16K33_I2CReadByte();
	VK16K33_I2CSendNAck();
	//STOPź
  VK16K33_I2CStop();
 
  return 0;
}

/*******************************************************************************
* Function Name  : VK16k33_Init
* Description    : VK16k33ʼ
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void VK16k33_Init(void)
{	
	GPIO_SetMode(VK16K33_SCL_PORT, VK16K33_SCL_PIN, GPIO_MODE_OUTPUT);
	GPIO_SetMode(VK16K33_SDA_PORT, VK16K33_SDA_PIN, GPIO_MODE_QUASI);
	           	
	VK16K33_SCL_HIGH;
	VK16K33_SDA_HIGH; 
	
	VK16K33WriteCmd(0x21); //ϵͳ
	VK16K33WriteCmd(0xa0); //INT/SEGΪSEG
	VK16K33WriteCmd(VK16K33_PDUTY_8_16); //8/16
	VK16K33WriteCmd(0x81); //ʾ˸ر
}
 
/*******************************************************************************
* Function Name  : VK16k33_Main
* Description    : VK16k33Գ
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/ 
void VK16k33_Main(void)
{   
	unsigned char i;
	
	VK16k33_Init();
	  
	for(i=0;i<16;i++)
	{
		write_buf[0]=0x00;
	}
	VK16K33WriteNData(0x00,write_buf,16);   //ȫ
	VK16K33_delay_nms(1000); 
	while(1)
	{
			for(i=0;i<16;i++)
			{
				write_buf[i]=0xff;
			}
			VK16K33WriteNData(0x00,write_buf,16);   //ȫ
		VK16K33_delay_nms(100); 
			for(i=0;i<16;i++)
			{
				write_buf[i]=0x00;
			}
			VK16K33WriteNData(0x00,write_buf,16);   //ȫ
		VK16K33_delay_nms(100);
		
		for(i=0;i<6;i++)
		{
			read_buf[i]=0x00;
		}
		VK16K33Readnkey(VK16K33_KEYSTARTADDR,6);  //
		VK16K33_delay_nms(200); 
//		if((vk16k33_key[0]!=0x7f)&&(vk16k33_key[1]!=0xff))
//		{
//			for(i=0;i<16;i++)
//			{
//				write_buf[i]=0xFF;
//			}
//			VK16K33WriteNData(0x00,write_buf,16);   //ȫ
//		VK16K33_delay_nms(1000); 
//		}
//		if((vk16k33_key[1]!=0xbf)&&(vk16k33_key[1]!=0xff))
//		{
//			for(i=0;i<16;i++)
//			{
//				write_buf[i]=0x00;
//			}
//			VK16K33WriteNData(0x00,write_buf,16);   //ȫ
//		VK16K33_delay_nms(1000); 
//		}


		__nop();
	}
}   
/************************END OF FILE****/ 
